@@ -1,7 +1,7 @@
-#   @(#)$Id: Configure.pm,v 100.12 2002/12/19 23:24:49 jleffler Exp $ 
+#   @(#)$Id: Configure.pm,v 100.14 2003/10/17 20:02:47 jleffler Exp $ 
 #
 #   Informix ESQL/C Support Routines for DBD::Informix
-#   (IBM Informix Database Driver for Perl Version 2003.04 (2003-03-05))
+#   (IBM Informix Database Driver for Perl DBI Version 2005.01 (2005-03-14))
 #
 #   Copyright 1999 Jonathan Leffler
 #   Copyright 2000 Informix Software Inc
@@ -25,7 +25,7 @@
 	@ISA = qw(Exporter);
 	@EXPORT = qw(find_informixdir_and_esql get_esqlc_version map_informix_lib_names);
 
-	$VERSION = "2003.04";
+	$VERSION = "2005.01";
 	$VERSION = "0.97002" if ($VERSION =~ m%[:]VERSION[:]%);
 
 	use strict;
@@ -48,16 +48,15 @@
 				if( -x "$p/ESQL.EXE")
 				{
 					# HUMS: \\ needed, because string goes into Makefile (via postamble)
-					$esql="$p\\ESQL.EXE"; 
+					$esql = "$p\\ESQL.EXE"; 
 					# HUMS: \\ necessary because string comes from ENV
-					$p  =~ s/\\BIN//i;
-					$ID=$p;
+					$p  =~ s%[/\\]BIN%%i;
+					$ID = $p;
 					last;
 				}
 			}
 			&did_not_read('No executable ESQL/C compiler found in $PATH')
 				unless defined $esql;
-			print "Using INFORMIXDIR=$ID and ESQL/C compiler $esql\n";
 		}
 		else
 		{
@@ -83,6 +82,7 @@
 						$ENV{PATH} =~ m%^$ID/bin:% ||
 						$ENV{PATH} =~ m%:$ID/bin$%);
 		}
+		print "Using INFORMIXDIR=$ID and ESQL/C compiler $esql\n";
 		return $ID, $esql;
 	}
 
@@ -96,10 +96,17 @@
 		my ($infv, $vers);
 
 		open(ESQL, "$esql -V|") || die;
-		die "Failed to read anything from 'esql -V'\n"
-			unless defined ($infv = <ESQL>);
-		# Read the rest of the input (1 line) to avoid Broken Pipe messages
-		while(<ESQL>) { }
+		# Read all the input to avoid Broken Pipe messages, and to avoid
+		# problems with RedHat 9 wittering about the ESQL/C compiler being
+		# an "Incorrectly built binary which accesses errno, ...".  Last
+		# version line wins!  Jay Hannah <jhannah@omnihotels.com> gets the
+		# credit for reporting the RedHat 9 problem.
+		while (<ESQL>)
+		{
+			$infv = $_ if (m%Informix.* Version%i);
+		}
+		die "Failed to read any Informix version from 'esql -V'\n"
+			unless defined $infv;
 		close ESQL;
 
 		chomp($infv);
@@ -221,7 +228,7 @@ use DBD::Informix::Configure;
 
 =head1 DESCRIPTION
 
-This module is used by IBM Informix Database Driver for Perl Version 2003.04 (2003-03-05) in the build and bug reporting code.
+This module is used by IBM Informix Database Driver for Perl DBI Version 2005.01 (2005-03-14) in the build and bug reporting code.
 You will seldom if ever have cause to use this module directly.
 
 =head2 Using find_informixdir_and_esql
